@@ -20,10 +20,10 @@
  * Author: Jonas Danielsson <jonas@threetimestwo.org>
  */
 
-const _ = imports.gettext.gettext;
-
 const Geocode = imports.gi.GeocodeGlib;
+const GLib = imports.gi.GLib;
 const Lang = imports.lang;
+const Translations = imports.translations;
 
 const Place = new Lang.Class({
     Name: 'Place',
@@ -97,6 +97,10 @@ const Place = new Lang.Class({
         return this._openingHours;
     },
 
+    get openingHoursTranslated() {
+        return Translations.translateOpeningHours(this._openingHours);
+    },
+
     set wheelchair(v) {
         this._wheelchair = v;
     },
@@ -140,6 +144,7 @@ const Place = new Lang.Class({
         }
     },
 
+
     toJSON: function() {
         let bounding_box = null;
 
@@ -176,6 +181,23 @@ const Place = new Lang.Class({
                  wiki: this.wiki,
                  wheelchair: this.wheelchair,
                  openingHours: this.openingHours };
+    },
+
+    match: function(searchString) {
+        let name = this.name;
+
+        searchString = GLib.utf8_normalize(searchString, -1, GLib.NormalizeMode.ALL);
+        if (searchString === null)
+            return false;
+
+        if (searchString.length === 0)
+            return true;
+
+        name = GLib.utf8_normalize(name, -1, GLib.NormalizeMode.ALL);
+        if (name === null)
+            return false;
+
+        return name.toLowerCase().search(searchString.toLowerCase()) !== -1;
     }
 });
 
